@@ -89,6 +89,8 @@ from synctera_client.apis.paths.monitoring_alerts import MonitoringAlerts
 from synctera_client.apis.paths.monitoring_alerts_alert_id import MonitoringAlertsAlertId
 from synctera_client.apis.paths.monitoring_subscriptions import MonitoringSubscriptions
 from synctera_client.apis.paths.monitoring_subscriptions_subscription_id import MonitoringSubscriptionsSubscriptionId
+from synctera_client.apis.paths.notes import Notes
+from synctera_client.apis.paths.notes_note_id import NotesNoteId
 from synctera_client.apis.paths.payment_schedules import PaymentSchedules
 from synctera_client.apis.paths.payment_schedules_payments import PaymentSchedulesPayments
 from synctera_client.apis.paths.payment_schedules_payment_schedule_id import PaymentSchedulesPaymentScheduleId
@@ -220,6 +222,8 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.MONITORING_ALERTS_ALERT_ID: MonitoringAlertsAlertId,
         PathValues.MONITORING_SUBSCRIPTIONS: MonitoringSubscriptions,
         PathValues.MONITORING_SUBSCRIPTIONS_SUBSCRIPTION_ID: MonitoringSubscriptionsSubscriptionId,
+        PathValues.NOTES: Notes,
+        PathValues.NOTES_NOTE_ID: NotesNoteId,
         PathValues.PAYMENT_SCHEDULES: PaymentSchedules,
         PathValues.PAYMENT_SCHEDULES_PAYMENTS: PaymentSchedulesPayments,
         PathValues.PAYMENT_SCHEDULES_PAYMENT_SCHEDULE_ID: PaymentSchedulesPaymentScheduleId,
@@ -352,6 +356,8 @@ path_to_api = PathToApi(
         PathValues.MONITORING_ALERTS_ALERT_ID: MonitoringAlertsAlertId,
         PathValues.MONITORING_SUBSCRIPTIONS: MonitoringSubscriptions,
         PathValues.MONITORING_SUBSCRIPTIONS_SUBSCRIPTION_ID: MonitoringSubscriptionsSubscriptionId,
+        PathValues.NOTES: Notes,
+        PathValues.NOTES_NOTE_ID: NotesNoteId,
         PathValues.PAYMENT_SCHEDULES: PaymentSchedules,
         PathValues.PAYMENT_SCHEDULES_PAYMENTS: PaymentSchedulesPayments,
         PathValues.PAYMENT_SCHEDULES_PAYMENT_SCHEDULE_ID: PaymentSchedulesPaymentScheduleId,
