@@ -15,6 +15,7 @@ from synctera_client.apis.tags.businesses_api import BusinessesApi
 from synctera_client.apis.tags.cards_api import CardsApi
 from synctera_client.apis.tags.external_cards_api import ExternalCardsApi
 from synctera_client.apis.tags.cash_pickups_alpha_api import CashPickupsAlphaApi
+from synctera_client.apis.tags.compliance_rules_api import ComplianceRulesApi
 from synctera_client.apis.tags.compliance_searches_api import ComplianceSearchesApi
 from synctera_client.apis.tags.customers_api import CustomersApi
 from synctera_client.apis.tags.disclosures_api import DisclosuresApi
@@ -76,6 +77,7 @@ TagToApi = typing_extensions.TypedDict(
         TagValues.CARDS: CardsApi,
         TagValues.EXTERNAL_CARDS: ExternalCardsApi,
         TagValues.CASH_PICKUPS_ALPHA: CashPickupsAlphaApi,
+        TagValues.COMPLIANCE_RULES: ComplianceRulesApi,
         TagValues.COMPLIANCE_SEARCHES: ComplianceSearchesApi,
         TagValues.CUSTOMERS: CustomersApi,
         TagValues.DISCLOSURES: DisclosuresApi,
@@ -138,6 +140,7 @@ tag_to_api = TagToApi(
         TagValues.CARDS: CardsApi,
         TagValues.EXTERNAL_CARDS: ExternalCardsApi,
         TagValues.CASH_PICKUPS_ALPHA: CashPickupsAlphaApi,
+        TagValues.COMPLIANCE_RULES: ComplianceRulesApi,
         TagValues.COMPLIANCE_SEARCHES: ComplianceSearchesApi,
         TagValues.CUSTOMERS: CustomersApi,
         TagValues.DISCLOSURES: DisclosuresApi,
