@@ -124,6 +124,7 @@ from synctera_client.model.change_channel import ChangeChannel
 from synctera_client.model.change_type import ChangeType
 from synctera_client.model.clearing_model import ClearingModel
 from synctera_client.model.client_token import ClientToken
+from synctera_client.model.content import Content
 from synctera_client.model.create_card_image_request import CreateCardImageRequest
 from synctera_client.model.create_gateway_request import CreateGatewayRequest
 from synctera_client.model.currency_code import CurrencyCode
@@ -232,6 +233,9 @@ from synctera_client.model.monitoring_status import MonitoringStatus
 from synctera_client.model.monitoring_subscription import MonitoringSubscription
 from synctera_client.model.monitoring_subscription_list import MonitoringSubscriptionList
 from synctera_client.model.network_fee_model import NetworkFeeModel
+from synctera_client.model.note_create import NoteCreate
+from synctera_client.model.note_list import NoteList
+from synctera_client.model.note_response import NoteResponse
 from synctera_client.model.original_credit_request_model import OriginalCreditRequestModel
 from synctera_client.model.original_credit_sender_data import OriginalCreditSenderData
 from synctera_client.model.originating_account_id import OriginatingAccountId
@@ -253,6 +257,7 @@ from synctera_client.model.patch_customer import PatchCustomer
 from synctera_client.model.patch_document import PatchDocument
 from synctera_client.model.patch_external_account import PatchExternalAccount
 from synctera_client.model.patch_interest import PatchInterest
+from synctera_client.model.patch_note import PatchNote
 from synctera_client.model.patch_payment_schedule import PatchPaymentSchedule
 from synctera_client.model.patch_person import PatchPerson
 from synctera_client.model.patch_person_business_owner_relationship import PatchPersonBusinessOwnerRelationship
@@ -313,7 +318,10 @@ from synctera_client.model.recipient_name import RecipientName
 from synctera_client.model.reconciliation import Reconciliation
 from synctera_client.model.reconciliation_input import ReconciliationInput
 from synctera_client.model.reconciliation_list import ReconciliationList
+from synctera_client.model.related_resource_field import RelatedResourceField
+from synctera_client.model.related_resource_id import RelatedResourceId
 from synctera_client.model.related_resource_type import RelatedResourceType
+from synctera_client.model.related_resource_type1 import RelatedResourceType1
 from synctera_client.model.relationship import Relationship
 from synctera_client.model.relationship1 import Relationship1
 from synctera_client.model.relationship_in import RelationshipIn
@@ -354,6 +362,7 @@ from synctera_client.model.statement_list import StatementList
 from synctera_client.model.statement_summary import StatementSummary
 from synctera_client.model.status import Status
 from synctera_client.model.status1 import Status1
+from synctera_client.model.status2 import Status2
 from synctera_client.model.template_fields import TemplateFields
 from synctera_client.model.template_fields_charge_secured import TemplateFieldsChargeSecured
 from synctera_client.model.template_fields_depository import TemplateFieldsDepository
@@ -361,6 +370,7 @@ from synctera_client.model.template_fields_generic_response import TemplateField
 from synctera_client.model.template_fields_line_of_credit import TemplateFieldsLineOfCredit
 from synctera_client.model.template_list import TemplateList
 from synctera_client.model.tenant_id import TenantId
+from synctera_client.model.tenant_id1 import TenantId1
 from synctera_client.model.tenant_id_internal import TenantIdInternal
 from synctera_client.model.three_ds_policy import ThreeDsPolicy
 from synctera_client.model.token_list import TokenList
@@ -382,6 +392,7 @@ from synctera_client.model.transfer_reversal_request import TransferReversalRequ
 from synctera_client.model.transfer_type import TransferType
 from synctera_client.model.transfer_type_request import TransferTypeRequest
 from synctera_client.model.txn_enhancer import TxnEnhancer
+from synctera_client.model.type import Type
 from synctera_client.model.update_card_image_request import UpdateCardImageRequest
 from synctera_client.model.update_gateway_request import UpdateGatewayRequest
 from synctera_client.model.update_transfer import UpdateTransfer
